pub struct CscCol<'a, T> { /* private fields */ }Expand description
An immutable representation of a column in a CSC matrix.
Implementations
Sourceimpl<'a, T> CscCol<'a, T>
impl<'a, T> CscCol<'a, T>
Sourcepub fn row_indices(&self) -> &[usize]
pub fn row_indices(&self) -> &[usize]
The row indices corresponding to explicitly stored entries in this column.
Sourcepub fn values(&self) -> &[T]
pub fn values(&self) -> &[T]
The values corresponding to explicitly stored entries in this column.
Sourcepub fn get_entry(&self, global_row_index: usize) -> Option<SparseEntry<'_, T>>
pub fn get_entry(&self, global_row_index: usize) -> Option<SparseEntry<'_, T>>
Returns an entry for the given global row index.
Each call to this function incurs the cost of a binary search among the explicitly stored row entries.