pub struct CscColMut<'a, T> { /* private fields */ }Expand description
A mutable representation of a column in a CSC matrix.
Note that only explicitly stored entries can be mutated. The sparsity pattern belonging to the column cannot be modified.
Implementations
Sourceimpl<'a, T> CscColMut<'a, T>
impl<'a, T> CscColMut<'a, T>
Sourcepub fn row_indices(&self) -> &[usize]
pub fn row_indices(&self) -> &[usize]
The row indices corresponding to explicitly stored entries in this column.
Sourcepub fn values(&self) -> &[T]
pub fn values(&self) -> &[T]
The values corresponding to explicitly stored entries in this column.
Sourcepub fn get_entry(&self, global_row_index: usize) -> Option<SparseEntry<'_, T>>
pub fn get_entry(&self, global_row_index: usize) -> Option<SparseEntry<'_, T>>
Returns an entry for the given global row index.
Each call to this function incurs the cost of a binary search among the explicitly stored row entries.
Sourceimpl<'a, T> CscColMut<'a, T>
impl<'a, T> CscColMut<'a, T>
Sourcepub fn values_mut(&mut self) -> &mut [T]
pub fn values_mut(&mut self) -> &mut [T]
Mutable access to the values corresponding to explicitly stored entries in this column.
Sourcepub fn rows_and_values_mut(&mut self) -> (&[usize], &mut [T])
pub fn rows_and_values_mut(&mut self) -> (&[usize], &mut [T])
Provides simultaneous access to row indices and mutable values corresponding to the explicitly stored entries in this column.
This method primarily facilitates low-level access for methods that process data stored in CSC format directly.
Sourcepub fn get_entry_mut(
&mut self,
global_row_index: usize,
) -> Option<SparseEntryMut<'_, T>>
pub fn get_entry_mut( &mut self, global_row_index: usize, ) -> Option<SparseEntryMut<'_, T>>
Returns a mutable entry for the given global row index.