#[non_exhaustive]
pub enum SparseFormatErrorKind {
IndexOutOfBounds,
DuplicateEntry,
InvalidStructure,
}Expand description
The type of format error described by a SparseFormatError.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
IndexOutOfBounds
Indicates that the index data associated with the format contains at least one index out of bounds.
DuplicateEntry
Indicates that the provided data contains at least one duplicate entry, and the current format does not support duplicate entries.
InvalidStructure
Indicates that the provided data for the format does not conform to the high-level structure of the format.
For example, the arrays defining the format data might have incompatible sizes.