CscSymbolicCholesky

Struct CscSymbolicCholesky 

pub struct CscSymbolicCholesky { /* private fields */ }
A symbolic sparse Cholesky factorization of a CSC matrix.

The symbolic factorization computes the sparsity pattern of L, the Cholesky factor.

Implementations

Source

impl CscSymbolicCholesky

pub fn factor(pattern: SparsityPattern) -> Self

Compute the symbolic factorization for a sparsity pattern belonging to a CSC matrix.

The sparsity pattern must be symmetric. However, this is not enforced, and it is the responsibility of the user to ensure that this property holds.

Panics

Panics if the sparsity pattern is not square.

pub fn l_pattern(&self) -> &SparsityPattern

The pattern of the Cholesky factor L.