Struct nalgebra_sparse::io::MatrixMarketError
source · [−]pub struct MatrixMarketError { /* private fields */ }Expand description
A description of the error that occurred during importing a matrix from a matrix market format data.
Implementations