pub enum Op<T> {
NoOp(T),
Transpose(T),
}Expand description
Determines whether a matrix should be transposed in a given operation.
See the module-level documentation for the purpose of this enum.
Variants
NoOp(T)
Indicates that the matrix should be used as-is.
Transpose(T)
Indicates that the matrix should be transposed.
Implementations
Sourceimpl<T> Op<T>
impl<T> Op<T>
Sourcepub fn inner_ref(&self) -> &T
pub fn inner_ref(&self) -> &T
Returns a reference to the inner value that the operation applies to.
Sourcepub fn map_same_op<U, F: FnOnce(T) -> U>(self, f: F) -> Op<U>
pub fn map_same_op<U, F: FnOnce(T) -> U>(self, f: F) -> Op<U>
Transforms the inner value with the provided function, but preserves the operation.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the Op and returns the inner value.
Sourcepub fn transposed(self) -> Self
pub fn transposed(self) -> Self
Applies the transpose operation.
This operation follows the usual semantics of transposition. In particular, double transposition is equivalent to no transposition.