#[non_exhaustive]
pub enum SparsityPatternFormatError {
InvalidOffsetArrayLength,
InvalidOffsetFirstLast,
NonmonotonicOffsets,
MinorIndexOutOfBounds,
DuplicateEntry,
NonmonotonicMinorIndices,
}Expand description
Error type for SparsityPattern format errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidOffsetArrayLength
Indicates an invalid number of offsets.
The number of offsets must be equal to (major_dim + 1).
InvalidOffsetFirstLast
Indicates that the first or last entry in the offset array did not conform to specifications.
The first entry must be 0, and the last entry must be exactly one greater than the major dimension.
NonmonotonicOffsets
Indicates that the major offsets are not monotonically increasing.
MinorIndexOutOfBounds
One or more minor indices are out of bounds.
DuplicateEntry
One or more duplicate entries were detected.
Two entries are considered duplicates if they are part of the same major lane and have the same minor index.
NonmonotonicMinorIndices
Indicates that minor indices are not monotonically increasing within each lane.